package ch.phoenix.oss.quarkus.commons.tracing;

import static org.mockito.ArgumentMatchers.eq;
import static org.mockito.ArgumentMatchers.startsWith;
import static org.mockito.Mockito.verify;
import static org.mockito.Mockito.verifyNoMoreInteractions;

import io.quarkus.test.junit.QuarkusTest;
import io.quarkus.test.junit.mockito.InjectSpy;
import io.restassured.RestAssured;
import io.restassured.http.ContentType;
import org.junit.jupiter.api.Test;

@QuarkusTest
class ActorTest {

    @InjectSpy
    TracingService tracingService;

    @Test
    void getAuthenticated() {
        var route = "/authenticated";
        RestAssured.given()
                .auth()
                .basic("jon", "doe")
                .accept(ContentType.TEXT)
                .when()
                .get(route)
                .then()
                .statusCode(200);

        verify(tracingService).trace("actor", "jon");
        verify(tracingService).trace("request.method", "GET");
        verify(tracingService).trace("request.route", route);
        verify(tracingService).trace("request.headers.accept", "text/plain");
        verify(tracingService).trace("request.headers.accept-encoding", "gzip,deflate");
        verify(tracingService).trace("request.headers.authorization", "********");
        verify(tracingService).trace("request.headers.connection", "Keep-Alive");
        verify(tracingService).trace(eq("request.headers.host"), startsWith("localhost:"));
        verify(tracingService).trace(eq("request.headers.user-agent"), startsWith("Apache-HttpClient"));
        verify(tracingService).trace("request.client.ip", "127.0.0.1");
        verifyNoMoreInteractions(tracingService);
    }
}
